<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 *
 */

function optionsframework_option_name() {
	// This gets the theme name from the stylesheet (lowercase and without spaces)
	$themename = get_option( 'stylesheet' );
	$themename = preg_replace("/\W/", "_", strtolower($themename) );

	$optionsframework_settings = get_option('optionsframework');
	$optionsframework_settings['id'] = $themename;
	update_option('optionsframework', $optionsframework_settings);
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 */

function optionsframework_options() {

	$options = array();

	// Header Options Area
	$options[] = array(
		'name' => __( 'سربرگ', 'accelerate' ),
		'type' => 'heading'
	);

	// Header Logo upload option
	$options[] = array(
		'name' 	=> __( 'لوگوی سربرگ', 'accelerate' ),
		'desc' 	=> __( 'یک لوگو برای سربرگ بارگذاری کنید. اندازه پیشنهادی 100 X 100 است ولی هر اندازه‌ای بخواهید می‌توانید بارگذاری کنید.', 'accelerate' ),
		'id' 		=> 'accelerate_header_logo_image',
		'type' 	=> 'upload'
	);

	// Header logo and text display type option
	$header_display_array = array(
		'logo_only' 	=> __( 'فقط لوگوی سربرگ', 'accelerate' ),
		'text_only' 	=> __( 'فقط متن سربرگ', 'accelerate' ),
		'both' 			=> __( 'نمایش هر دو', 'accelerate' ),
		'none'		 	=> __( 'غیرفعال', 'accelerate' )
	);
	$options[] = array(
		'name' 		=> __( 'نمایش', 'accelerate' ),
		'desc' 		=> __( 'گزینه‌ای که می‌خواهید را انتخاب کنید.', 'accelerate' ),
		'id' 			=> 'accelerate_show_header_logo_text',
		'std' 		=> 'text_only',
		'type' 		=> 'radio',
		'options' 	=> $header_display_array 
	);

	// Header Image replace postion
	$options[] = array(
		'name' => __( 'نیاز به افزودن ابزارک سربرگ دارید؟', 'accelerate' ),
		'desc' => sprintf( __( '<a href="%1$s">اینجا کلیک کنید</a> &nbsp;&nbsp; کافی است ابزارک‌های را که مایل هستید به ستون کناری سربرگ اضافه کنید..', 'accelerate' ), admin_url('widgets.php') ),
		'type' => 'info'
	);

	// Header Image replace postion
	$options[] = array(
		'name' => __( 'نیاز به جایگزینی تصویر سربرگ دارید؟', 'accelerate' ),
		'desc' => sprintf( __( '<a href="%1$s">اینجا کلیک کنید</a> &nbsp;&nbsp; شما می‌توانید مکان تصویر را با گزینه زیر تغییر دهید.', 'accelerate' ), admin_url('themes.php?page=custom-header') ),
		'type' => 'info'
	);

	// Header image position option
	$options[] = array(
		'name' 		=> __( 'مکان تصویر سربرگ', 'accelerate' ),
		'desc' 		=> __( 'مکان تصویر سربرگ را مشخص کنید.', 'accelerate' ),
		'id' 			=> 'accelerate_header_image_position',
		'std' 		=> 'position_two',
		'type' 		=> 'radio',
		'options' 	=> array(
							'position_one' => __( 'مکان اول: نمایش تصویر بالای متن/عنوان سایت.', 'accelerate' ),
							'position_two' => __( 'مکان دوم (پیشفرض): نمایش تصویر بین عنوان و فهرست اصلی.', 'accelerate' ),
							'position_three' => __( 'مکان سوم: نمایش تصویر زیر فهرست اصلی.', 'accelerate' )
						)

	);

	/*************************************************************************/

	$options[] = array(
		'name' => __( 'طراحی', 'accelerate' ),
		'type' => 'heading'
	);

	$options[] = array(
		'name' 		=> __( 'طرح‌بندی سایت', 'accelerate' ),
		'desc' 		=> __( 'طرح‌بندی سایت را انتخاب کنید. این بر روی همه قسمت‌های سایت تاثیر خواهد گذاشت.', 'accelerate' ),
		'id' 			=> 'accelerate_site_layout',
		'std' 		=> 'wide',
		'type' 		=> 'radio',
		'options' 	=> array(
							'box' 	=> __( 'طرح‌بندی جعبه‌ای', 'accelerate' ),
							'wide' 	=> __( 'طرح‌بندی عریض', 'accelerate' )
						)
	);

	$options[] = array(
		'name' 		=> __( 'طرح‌بندی پیشفرض', 'accelerate' ),
		'desc' 		=> __( 'طرح‌بندی پیشفرض در بایگانی، جستجو و...', 'accelerate' ),
		'id' 			=> 'accelerate_default_layout',
		'std' 		=> 'right_sidebar',
		'type' 		=> 'images',
		'options' 	=> array(
								'left_sidebar' 	=> ACCELERATE_ADMIN_IMAGES_URL . '/right-sidebar.png',
								'right_sidebar' 		=> ACCELERATE_ADMIN_IMAGES_URL . '/left-sidebar.png',
								'no_sidebar_full_width'				=> ACCELERATE_ADMIN_IMAGES_URL . '/no-sidebar-full-width-layout.png',
								'no_sidebar_content_centered'		=> ACCELERATE_ADMIN_IMAGES_URL . '/no-sidebar-content-centered-layout.png',
							)
	);

	$options[] = array(
		'name' 		=> __( 'طرح‌بندی پیشفرض فقط برای برگه‌ها', 'accelerate' ),
		'desc' 		=> __( 'طرح‌بندی پیشفرض برای برگه‌ها را انتخاب کنید.', 'accelerate' ),
		'id' 			=> 'accelerate_pages_default_layout',
		'std' 		=> 'right_sidebar',
		'type' 		=> 'images',
		'options' 	=> array(
								'left_sidebar' 	=> ACCELERATE_ADMIN_IMAGES_URL . '/right-sidebar.png',
								'right_sidebar' 		=> ACCELERATE_ADMIN_IMAGES_URL . '/left-sidebar.png',
								'no_sidebar_full_width'				=> ACCELERATE_ADMIN_IMAGES_URL . '/no-sidebar-full-width-layout.png',
								'no_sidebar_content_centered'		=> ACCELERATE_ADMIN_IMAGES_URL . '/no-sidebar-content-centered-layout.png',
							)
	);

	$options[] = array(
		'name' 		=> __( 'طرح‌بندی پیشفرض فقط برای تک‌نوشته‌ها', 'accelerate' ),
		'desc' 		=> __( 'طرح‌بندی پیشفرض برای تک‌نوشته‌ها را انتخاب کنید.', 'accelerate' ),
		'id' 			=> 'accelerate_single_posts_default_layout',
		'std' 		=> 'right_sidebar',
		'type' 		=> 'images',
		'options' 	=> array(
								'left_sidebar' 	=> ACCELERATE_ADMIN_IMAGES_URL . '/right-sidebar.png',
								'right_sidebar' 		=> ACCELERATE_ADMIN_IMAGES_URL . '/left-sidebar.png',
								'no_sidebar_full_width'				=> ACCELERATE_ADMIN_IMAGES_URL . '/no-sidebar-full-width-layout.png',
								'no_sidebar_content_centered'		=> ACCELERATE_ADMIN_IMAGES_URL . '/no-sidebar-content-centered-layout.png',
							)
	);

	$options[] = array(
		'name' 		=> __( 'نوع نمایش نوشته‌های برگه', 'accelerate' ),
		'desc' 		=> __( 'نوع نمایش آخرین نوشته‌ها را انتخاب کنید.', 'accelerate' ),
		'id' 			=> 'accelerate_posts_page_display_type',
		'std' 		=> 'large_image',
		'type' 		=> 'radio',
		'options' 	=> array(
							'large_image' 	=> __( 'تصویر شاخص بزرگ', 'accelerate' ),
							'small_image' 	=> __( 'تصویر شاخص کوچک', 'accelerate' ),
							'small_image_alternate' 	=> __( 'تصویر شاخص کچک با کناره‌ها', 'accelerate' )
						)
	);

	// Site primary color option
	$options[] = array(
		'name' 		=> __( 'گزینه رنگ اصلی', 'accelerate' ),
		'desc' 		=> __( 'این در  پیوندها، دکمه‌ها و خیلی رنگ‌های دیگر تاثیر خواهد داشت.', 'accelerate' ),
		'id' 			=> 'accelerate_primary_color',
		'std' 		=> '#77CC6D',
		'type' 		=> 'color' 
	);	

	$options[] = array(
		'name' 		=> __( 'نیاز به جایگزینی پس‌زمینه پیشفرض دارید؟', 'accelerate' ),
		'desc' 		=> sprintf( __( '<a href="%1$s">اینجا کلیک کنید</a>', 'accelerate' ), admin_url('themes.php?page=custom-background') ).'&nbsp;&nbsp;&nbsp;'.__( 'توجه: فقط در حالی که طرح‌بندی جعبه‌ای را انتخاب کنید نمایش داده می‌شود.', 'accelerate' ),
		'type' 		=> 'info'
	);

	$options[] = array(
		'name' 		=> __( 'CSS دلخواه', 'accelerate' ),
		'desc' 		=> __( 'استایل دلخواه خود را بنویسید.', 'accelerate' ),
		'id' 			=> 'accelerate_custom_css',
		'std' 		=> '',
		'type' 		=> 'textarea'
	);

	/*************************************************************************/

	$options[] = array(
		'name' => __( 'اضافی', 'accelerate' ),
		'type' => 'heading'
	);

	// Favicon activate option
	$options[] = array(
		'name' 		=> __( 'فعال کردن favicon', 'accelerate' ),
		'desc' 		=> __( 'برای فعال کردن favicon تیک بزنید. یک فیو آیکون در زیر بارگذاری کنید', 'accelerate' ),
		'id' 			=> 'accelerate_activate_favicon',
		'std' 		=> '0',
		'type' 		=> 'checkbox'
	);

	// Fav icon upload option
	$options[] = array(
		'name' 	=> __( 'بارگذاری favicon', 'accelerate' ),
		'desc' 	=> __( 'بارگذاری favicon برای سایت شما.', 'accelerate' ),
		'id' 		=> 'accelerate_favicon',
		'type' 	=> 'upload'
	);

	/*************************************************************************/

	$options[] = array(
		'name' => __( 'اسلایدر', 'accelerate' ),
		'type' => 'heading'
	);

	// Slider activate option
	$options[] = array(
		'name' 		=> __( 'فعال کردن اسلایدر', 'accelerate' ),
		'desc' 		=> __( 'برای فعال کردن اسلایدر تیک بزنید.', 'accelerate' ),
		'id' 			=> 'accelerate_activate_slider',
		'std' 		=> '0',
		'type' 		=> 'checkbox'
	);

	$num_of_slides = 4;

	// Slide options
	for( $i=1; $i<=$num_of_slides; $i++) {
		$options[] = array(
			'name' 	=>	sprintf( __( 'اسلایدر #%1$s', 'accelerate' ), $i ),
			'desc' 	=> __( 'تصویر اسلایدر', 'accelerate' ),
			'id' 		=> 'accelerate_slider_image'.$i,
			'type' 	=> 'upload'
		);
		$options[] = array(
			'desc' 	=> __( 'عنوان این اسلایدر را وارد کنید', 'accelerate' ),
			'id' 		=> 'accelerate_slider_title'.$i,
			'std' 	=> '',
			'type' 	=> 'text'
		);
		$options[] = array(
			'desc' 	=> __( 'توضیح این اسلایدر را وارد کنید', 'accelerate' ),
			'id' 		=> 'accelerate_slider_text'.$i,
			'std' 	=> '',
			'type' 	=> 'textarea'
		);
		$options[] = array(
		'desc' 		=> __( 'مکان متن اسلایدر.', 'accelerate' ),
		'id' 			=> 'accelerate_slide_text_position'.$i,
		'std' 		=> 'right',
		'type' 		=> 'radio',
		'options' 	=> array(
							'right' 	=> __( 'سمت چپ', 'accelerate' ),
							'left' 	=> __( 'سمت راست', 'accelerate' )
						)
	);
		$options[] = array(
			'desc' 	=> __( 'پیوند برای انتقال اسلاید را وارد کنید', 'accelerate' ),
			'id' 		=> 'accelerate_slider_link'.$i,
			'std' 	=> '',
			'type' 	=> 'text'
		);
	}

	return $options;
}

add_action( 'optionsframework_after','accelerate_options_display_sidebar' );

?>